## Data dictionary (missing indicator = NA)

# bwt = birth weight in grams (continuous).
# low = low birth weight indicator: low vs norm (factor, reference  = low)
# age = mother's age in years (continuous).
# lwt = mother's weight in pounds at last menstrual period (continuous).
# race2 = mother's race (white vs nonwhite) (factor, reference = nonwhite)
# race3 = mother's race (white vs black vs other) (factor, reference = black)
# smoke = smoking status during pregnancy  yes vs no (factor, reference=no)
# ptd = history of preterm delivery yes vs no (factor, reference=no)
# ht = maternal hypertension yes vs no (factor, reference=no)
# ui = presence of uterine irritability yes vs no (factor, reference=no)
# ftv = number of physician visits during the first trimester (continuous, 0-6)

# First set working directory (Sessions: Set Working Directory)
# read data, define our factors, and create any new variables
 d=read.csv("bwt.csv") # read .csv spreadsheet
 d$low=relevel(d$low, ref="norm")
 d$race2=relevel(d$race2, ref="white")
 d$race3=factor(d$race3, levels=c("white", "black","other"));

 # save R data file to working directory
 save(d,file="d") # save d as a file
 load("d") # re-load dataframe with original names, formats
 summary(d)  # confirm revised dataframe reloaded

 # DESCRIPTIVE STATISTICS
 mean(d$bwt) # apply mean function to individual variables as vectors
 var(d$bwt)
 sd(d$bwt) # same as sqrt(var(d$bwt))
 min(d$bwt)
 max(d$bwt)
 range(d$bwt) # same as min(bwt), max(bwt)
 median(d$bwt)
 quantile(d$bwt, probs=c(0.1, 0.25,0.5, 0.75, 0.9)) # sample percentiles

 summary(d) #  basic descriptives (5 number)
 library(Hmisc) # load package for 'describe()`
 describe(d) # more comprehensive descriptives

 # CORRELATIONS/COVARIANCES
 cor(d$bwt, d$lwt) # Pearson correlation between two numerics
 with(d, cor(bwt, lwt)) # alternatively, the same but more efficiently
 with(d, cor(bwt, lwt, method="kendall")) # non-parametric Kendall tau
 with(d, cor(bwt, lwt, method="spearman")) # non-parametric Spearman rho

 with(d, cor.test(bwt, lwt)) # test of significance Pearson r, 95% CI
 with(d, cor.test(bwt, lwt, method="kendall")) # concordance based correlation
 with(d, cor.test(bwt, lwt, method="spearman")) # rank based correlation

 with(d, cor.test(bwt, lwt, conf.level=0.90))

 names(d) # to identify the numeric variables i.e. columns 1, 3, 4, 7
 d1=d[, c(1,3,4,7)] # d1 contains just the numeric variables
 cor(d1) # correlation matrix with 1's on diagonal
 cov(d1)  # covariance matrix with variances on the diagnonal

# Exercise: Pearson r with 90% CI


 # Corr plot
 library(ggcorrplot)
 p.mat = cor_pmat(d[, c(1,3,4,7)])
 ggcorrplot(cor(d[, c(1,3,4,7)]),  insig="pch", pch="-", p.mat=p.mat, type="full", title="- for p > 0.05")

 # mean, sd apply to just continuous data
 sapply(d[, c(1,3,4,7)], mean)
 sapply(d[, c(1,3,4,7)], sd)

 # apply function=summary to bwt by race3
 with(d, tapply(bwt, race3, summary))

 #CONTINGENCY TABLES for factors (categorical variables)
 with(d, table(race3))

 # tables can be named objects-> manipulated, tested, plotted
 tab1=with(d, table(race3));tab1 # now present in Environment window
 tab2=with(d, table(low, race3));tab2

 # tables can be manipulated, plotted (see barplot)
 addmargins(tab2) # add row and column totals
 prop.table(tab2, margin=2) # margin = 2 for column proportions
 prop.table(tab2, margin=1) # margin = 1 for row proportions


 tab3=with(d, table(low, race3, smoke));tab3


 ftable(tab3) # flatten 2D table

 # EXERCISE:play with order: smoke vs lbw by race


 # subset normotensive non-smokers only into dataset d1 (& = logical AND)
 d2=subset(d, smoke=="no" & ht=="no");dim(d2) # drop 81 rows
 head(d2) # same variables as d

 # restrict table() to new dataframe d2
 tab4=with(d2, table(low, race3));tab4
 tab4=table(d2$low, d2$race3);tab4


 ## GRAPHING CONTINUOUS DATA
 with(d, hist(bwt)) # basic command
 with(d, hist(x=bwt, breaks=20, col="lightblue",  main="Birth Weight Distribution", xlab="Birth Weight (g)"))

 abline(v=median(d$bwt), col="red", lty="dashed", lwd=2) # add median, lwd=width
 abline(v=quantile(d$bwt, probs=c(0.25, 0.75)), col="royalblue", lty="dashed", lwd=2) # add IQR

 # kernel density plot
 plot(density(d$bwt))
 plot(density(d$bwt, bw=125), main="Age Distribution") #adjust bandwidth
 plot(density(d$bwt, bw=400), main="Age Distribution") #adjust bandwidth

 # normal quantile-quantile plot in base R
 qqnorm(d$bwt)
 qqline(d$bwt) # add best-fit line

 # compare to qqplot in car package
 library(car) # load car
 qqPlot(d$bwt)
 qqPlot(d$bwt, main="Testing Normality", ylab="Birth Weight (g)", xlab="Theoretical Quantiles") # add decorations

 # EXERCISE: plot histogram, density, and QQ plot for maternal (age)


 #STEM AND LEAF PLOT
 stem(d$bwt)

 # EXERCISE: make stem and leaf plot for maternal age (age)

 #  XYPlots (numeric vs numeric)
 plot(bwt~lwt, data=d)

 unclass(d$race2) # 1 = white, 2 = non-white
 plot(bwt~lwt, data=d, col=unclass(race2), pch=19,  xlab="maternal weight",ylab="birth weight")

 # add best fit line with a=intecept, b=slope
 model1=lm(bwt~lwt, data=d)
 summary(model1)
 abline(model1, lty="dashed", col="grey39")

 # add text
 cor1=round(cor(d$bwt, d$lwt),2);cor1
 txt1=paste("r =", cor1);txt1
 text(x=225, y = 4800, labels=txt1)

 # add lowess (aka loess)
 lines(lowess(d$bwt~d$lwt), lty="solid", col="royalblue", lwd=2)

 # add legends
 legend(x="bottomright", col=c(1,2), pch=19, legend=c("white","nonwhite"), bty='n')

 legend(x="topleft", lty=c("solid","dashed"), col=c("royalblue","grey39"), legend=c("loess","linear"), bty='n')


## GRAPHING COUNT DATA
 # BOXPLOTS (numeric vs categorical)
 boxplot(bwt~race3, data=d, xlab="Race", ylab="Birthweight (g)")

 # EXERCISE: Plot birth weight vs maternal smoking

 #BARCHARTS: DISPLAY COUNTS
 tab1 # a vector
 barplot(tab1) # same as barplot(height=tab1)

 tab2 # a matrix (2 x 3)
 barplot(tab2) # same as barplot(height=tab2), rows -> bars
 barplot(tab2, density=c(20,10)) # shade bars for publication

 # decorate with plot options
 barplot(tab1, main="Newborn Racial Distribution", col=c("blue","red","yellow"), xlab="Race", ylab="Counts")
 legend("top", fill=c("blue","red", "yellow"), legend=c("white","black","other"), bty='n')

 # horiz=TRUE
 barplot(tab1, main="Newborn Racial Distribution", col=c("blue","red","yellow"), xlab="Counts", ylab="Race", horiz=TRUE)

 # grouped bar chart (beside=TRUE, horiz=TRUE)
 barplot(tab2, col=c("darkblue","red"), main="Racial distribution: LBW", xlab="Counts", ylab="Race", beside=TRUE, horiz=TRUE)
 legend("topright", fill=c("darkblue","red"), legend=c("Norm","Low"), bty='n', cex=0.8)

 # EXERCISE: stacked barplot low vs smoking


 # COMPARING MEANS
 # t-test bwt vs race2 (two.sided)
 t.test(bwt~race2, data=d)

 ?t.test # many options
 # one-sided hypothesis (group 1 > group 2 i.e. white > nonwhite)
 t.test(bwt~race2, data=d, alternative="greater")

 # Mann Whitney U: bwt vs race2 (Wilcoxon Rank Sum Test)
 wilcox.test(bwt~race2, data=d)
 wilcox.test(bwt~race2, data=d, alternative="greater")


 # ANOVA for 3 group comparison
 anova1=aov(bwt~race3, data=d)
 summary(anova1) # Overall test of significance
 TukeyHSD(anova1) # pairwise tests, adjusted for multiple comparisons

 # EXERCISE: compare bwt vs maternal smoking, parameteric and non-parametric
 t.test(bwt~smoke, data=d)
 wilcox.test(bwt~smoke, data=d)


 # EXERCISE - comparing birth weights in black and white newborns in the dataset. How does this p-value compare to TukeyHSD test?


 # EXERCISE: compare maternal weight by race3, adjusted for multiple comparisons

 ## COMPARING PROPORTIONS
 # CREATE TABLE OF COUNTS
 tab6=with(d, table(low, race2));tab6
 prop.table(tab6, margin=2) # margin = 2 i.e. column percent


 # TESTING COUNT DATA
 chisq.test(tab6)
 fisher.test(tab6) # if expected counts in any cell < 5

 # EXERCISE: test association between low, race 3 for normotensive, non-smokers
 tab4 # normotensive non-smokers
 
 # homework section 8 primer
